@@ -3,23 +3,21 @@ from typing import Optional
 
 import typer
 from rich import print
-# from tqdm import tqdm
-
-# from utils import f1
+from rich.progress import track
 from .video_duration import get_length, get_file_list
 
+# from utils import f1
 app = typer.Typer()
 
 
 @app.callback()
 def callback():
-    """Awesome Portal Gun"""
+    """Здесь наверное должно быть какое-то краткое описание программы"""
 
 
 @app.command()
 def print_something():
     """Напечатает заранее захардкоженый текст"""
-    # typer.echo("Shooting portal gun")
     print("[bold red]Alert![/bold red] [green]Portal gun[/green] shooting! :boom:")
 
 
@@ -33,8 +31,9 @@ def say_hello(name: str, city: Optional[str] = None):
 
 @app.command()
 def vd():
-    file_length_list = [get_length(i) for i in (get_file_list())]
-    total_video_duration = (sum(file_length_list))
+    """Показывает суммарную длительность видео в текущей папке и её подпапках"""
+    file_length_list = [get_length(i) for i in track(get_file_list())]
+    total_video_duration = sum(file_length_list)
     print(str(datetime.timedelta(seconds=int(total_video_duration))))
 
 
