@@ -1,6 +1,7 @@
 import subprocess
 import os
 import datetime
+
 # from tqdm import tqdm
 
 
@@ -10,17 +11,26 @@ def get_file_list():
 
     for i in tree:
         for j in i[2]:
-            if j.split('.')[-1] == 'mp4':
+            if j.split(".")[-1] == "mp4":
                 file_list.append(os.path.join(i[0], j))
     return file_list
 
 
 def get_length(filename):
-    result = subprocess.run(["ffprobe", "-v", "error", "-show_entries",
-                             "format=duration", "-of",
-                             "default=noprint_wrappers=1:nokey=1", filename],
-                            stdout=subprocess.PIPE,
-                            stderr=subprocess.STDOUT)
+    result = subprocess.run(
+        [
+            "ffprobe",
+            "-v",
+            "error",
+            "-show_entries",
+            "format=duration",
+            "-of",
+            "default=noprint_wrappers=1:nokey=1",
+            filename,
+        ],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
+    )
     return float(result.stdout)
 
 
